#
# spec file for package libupnpp
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2025 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define so_ver  17
Name:           libupnpp
Version:        1.0.2
Release:        1.1
Summary:        Library providing a higher level API over libnpupnp or libupnp
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://www.lesbonscomptes.com/upmpdcli/index.html
Source0:        https://www.lesbonscomptes.com/upmpdcli/downloads/libupnpp-%{version}.tar.gz
Source1:        https://www.lesbonscomptes.com/upmpdcli/downloads/libupnpp-%{version}.tar.gz.asc
Source2:        %{name}.keyring
BuildRequires:  c++_compiler
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libnpupnp) >= 6.0.0

%description
Libupnpp is a C++ wrapper for libupnp a.k.a Portable UPnP (up to branch 0.17),
or its C++ descendant, libnpupnp (versions 0.18 and later).

Libupnpp can be used to implement UPnP devices and services, or Control Points.
The Control Point side of libupnpp, which is documented here,
allows a C++ program to discover UPnP devices, and exchange commands and status with them.

%package -n %{name}%{so_ver}
Summary:        Library providing a higher level C++ API over libnpupnp or libupnp
Group:          System/Libraries

%description -n %{name}%{so_ver}
Libupnpp is a C++ wrapper for libupnp a.k.a Portable UPnP (up to branch 0.17),
or its C++ descendant, libnpupnp (versions 0.18 and later).

Libupnpp can be used to implement UPnP devices and services, or Control Points.
The Control Point side of libupnpp, which is documented here,
allows a C++ program to discover UPnP devices, and exchange commands and status with them.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{name}%{so_ver} = %{version}

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install

%check
%meson_test

%ldconfig_scriptlets -n %{name}%{so_ver}

%files -n %{name}%{so_ver}
%license COPYING LICENSE
%{_libdir}/*.so.%{so_ver}
%{_libdir}/*.so.%{version}

%files devel
%license COPYING LICENSE
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Fri Apr  4 2025 Michael Pujos <pujos.michael@gmail.com>
- update to 1.0.2:
  * Control: cdircontent: methods taking output parameters should clear them first
- update to 1.0.1:
  * Control: content directory: improve access to properties with multiple values
    or artist roles. API change.
  * Changed version to 1.0 because should now be stable
* Sun Mar  9 2025 Andreas Stieger <andreas.stieger@gmx.de>
- update to 0.26.8:
  * Control: directory: add provision to pass through vendor
    extension fields (upmpdcli only for now).
- license is LGPL-2.1-or-later
* Sun Nov 10 2024 Michael Pujos <pujos.michael@gmail.com>
- Update to version 0.26.7:
  * Control, directory: fix handling multiple instances of a property
    value (try to avoid duplicates)
  * Control, directory: List albumartist first, if present, in artist list
  * Control, directory: add property to each entry to communicate the exact
    order of the original content directory data (allows overriding the
    container/items separation in the libupnpp data)
* Thu Aug 22 2024 Michael Pujos <pujos.michael@gmail.com>
- Update to version 0.26.6:
  * Fix the qmake build to not need special copy of includes in uninstalled npupnp.
  * Fix gcc 14 compile (includes)
  * Misc. small cleanups, mostly compile/build
* Sun May 12 2024 Michael Pujos <pujos.michael@gmail.com>
- Update to version 0.26.4:
  * Changed the build system from autotools to meson
- Update to version 0.26.3:
  * Minuscule internal cleanups
- Update to version 0.26.2:
  * Control: fix worker count issue in workqueue
- Update to version 0.26.0:
  * Control: add interface to receive events for disappearing devices
    (UPnPDeviceDiscovery::addLostCallback())
  * More thorough cleanup on exit
* Sat Dec 23 2023 Michael Pujos <pujos.michael@gmail.com>
- Update to version 0.25.0:
  * Control: description: store the download url in the parsed
    description structure.
  * Control: make sure that the requested search window is not smaller
    than the npupnp minimum as this would result in insufficient waiting
    for the initial search.
  * Control: discovery: add interface to perform unicast search.
  * Add init option to pass a bootid value to libnpupnp.
- Update to version 0.24.1:
  * Don't extend URLs escaping by default (was causing issues with Yamaha
    renderers).
  * so version and debian packaging cleanup.
- Update to version 0.24.0:
  * Rebuilt for rpi 1 (armv6) compatibility
  * Control: ohproduct: export a parseSourceXML static method.
  * Control: add timeout optional parameters to OHRadio::id(),
    OHPlaylist::id(), and AVTransport::getPositionInfo(). Add options
    structure parameter to the base Service class methods.
- Update to version 0.23.0:
  * Device: added a LibUPnP::setWebServerDocumentRoot method, for
    activating the libnpupnp HTTP server local file service.
- Update to version 0.22.5:
  * Small internal changes: eliminate explicit memory allocations, improve
    url sanitizing.
- Update to version 0.23.3:
  * Control Point: sanitize unsufficiently quoted URLs from content
    directory.
* Sat Aug 13 2022 Michael Pujos <pujos.michael@gmail.com>
- Update to version 0.22.2:
  * Adapt to the npupnp Upnp_SID type change
- Update to version 0.22.1:
  * Allow absolute eventSubURLs in the description.
    UPnP 1.1 is ambiguous on this point. They are  used by some renderers
    (e.g. LMS UPnP renderer plugin), which made them incompatible with
    libupnpp
- Update to version 0.22.0:
  * Improved logging of action errors: show what we were doing.
    Ajust other log message levels
  * Small stylistic changes
  * Interface of Songcast API had incompatible change, forced a new
    package name
* Sun Mar 20 2022 Andreas Stieger <andreas.stieger@gmx.de>
- add upstream siging key and validate source signature
* Thu Apr 15 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.21.0:
  * Allow configuring the subscription timeout (init option)
  * Add interface for the lib to report a subscription autorenewal
    failure, and to renew all subscriptions.
  * Add API to set the product/version values in User-Agent
    and Server headers.
- Modified description
* Wed Jan 20 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.20.2:
  * Content Directory interface: accept responses with 0 TotalMatches.
  * Adjust excessively noisy messages.
* Sun Nov 15 2020 Michael Pujos <pujos.michael@gmail.com>
- update to upstream version 0.20.0
* Fri Jan 24 2020 Michael Pujos <pujos.michael@gmail.com>
- Initial package for version 1.4.2
